import ky, { Options } from 'ky';
import {
  API_PROXY_PATH,
  ApiEndpoint,
  ApiEndpointTypes,
  ENDPOINTS_CONFIG,
  ESTUARY_API_PATH,
} from './endpoints';

// Defines whether to use Next.js API proxy (with automatic API_KEY injection),
// or Estuary API directly (without an API key)
const USE_API_PROXY = true;

export const request = <
  T extends ApiEndpoint | string,
  P extends T extends ApiEndpoint ? ApiEndpointTypes[T]['params'] : any,
  R extends T extends ApiEndpoint ? ApiEndpointTypes[T]['response'] : any,
>(
  endpoint: T,
  options: Omit<Options, 'method' | 'prefixUrl' | 'timeout'>,
) => {
  const endpointConfig =
    ENDPOINTS_CONFIG?.[endpoint as ApiEndpoint] ?? undefined;

  return ky(
    endpointConfig
      ? `${USE_API_PROXY ? API_PROXY_PATH : ESTUARY_API_PATH}${endpoint}`
      : endpoint,
    {
      method: endpointConfig?.method ?? undefined,
      ...options,
      timeout: false,
      redirect: 'follow',
    },
  );
};
