import React, { ReactNode } from 'react';
import { WithClassName } from '../../types/components';
import cn from 'classnames';

type CheckboxProps = WithClassName & {
  label: ReactNode;
  defaultChecked?: boolean;
  onChange?: (checked: boolean) => void;
  disabled?: boolean;
  toggle?: boolean;
};

export const Checkbox: React.FC<CheckboxProps> = ({
  id,
  className,
  label,
  defaultChecked,
  onChange,
  disabled,
  toggle,
}) => (
  <label
    htmlFor={id}
    className={cn(
      className,
      'label max-w-xs',
      disabled ? 'cursor-block' : 'cursor-pointer',
    )}
  >
    <span className="label-text">{label}</span>
    <input
      id={id}
      type="checkbox"
      className={cn(toggle ? 'toggle' : 'checkbox')}
      checked={defaultChecked}
      disabled={disabled}
      onChange={({ target: { checked } }) => {
        if (onChange) {
          onChange(checked);
        }
      }}
    />
  </label>
);
