import React, { useCallback, useMemo, useState } from 'react';
import { DropzoneOptions, useDropzone } from 'react-dropzone';
import tw from 'tailwind-styled-components';
import { WithClassName } from '../../types/components';

const DEFAULT_MAX_FILE_SIZE = 1024 * 1024 * 50; // 50MB

type Props = Omit<DropzoneOptions, 'multiple'> & WithClassName;

const Wrapper = tw.div`
  w-full 
  px-4 pt-12 pb-10 
  text-gray-300 
  font-medium 
  border border-neutral border-dashed 
  rounded-lg 
  text-center 
  cursor-pointer 
  hover:border-primary 
  transition-colors 
  select-none
`;

const FileInput: React.FC<Props> = ({
  maxSize = DEFAULT_MAX_FILE_SIZE,
  onDrop,
  id,
  className,
  ...rest
}) => {
  const [filename, setFilename] = useState<string | string[]>('');

  const maxSizeDisplay = useMemo(() => maxSize / (1024 * 1024), [maxSize]);

  // @ts-ignore
  const _onDrop = useCallback<DropzoneOptions['onDrop']>(
    (acceptedFiles, ...args) => {
      if (acceptedFiles.length > 0) {
        setFilename(acceptedFiles[0].name);
      }

      if (onDrop) {
        onDrop(acceptedFiles, ...args);
      }
    },
    [onDrop],
  );

  const { getRootProps, getInputProps, isDragActive } = useDropzone({
    multiple: false,
    maxSize,
    onDrop: _onDrop,
    ...rest,
  });

  return (
    <Wrapper {...getRootProps()} className={className}>
      <input id={id} {...getInputProps()} />
      {isDragActive ? (
        <p>Drop the file here...</p>
      ) : filename ? (
        <p>{filename.toString()}</p>
      ) : (
        <p>
          Drag &apos;n&apos; drop any file here, or click to select file
          <span className="block mt-1 text-gray-600">
            Max Size: {maxSizeDisplay}MB
          </span>
        </p>
      )}
    </Wrapper>
  );
};

export default FileInput;
