import React from 'react';
import { ComponentBase } from '../../types/components';
import cn from 'classnames';

type FormControlProps = ComponentBase & {
  label?: string;
  htmlFor?: string;
  hintTopRight?: string;
  hintBottomLeft?: string;
  hintBottomRight?: string;
  noBottomMargin?: boolean;
};

export const FormControl: React.FC<FormControlProps> = ({
  className,
  children,
  label,
  hintTopRight,
  hintBottomLeft,
  hintBottomRight,
  noBottomMargin = false,
}) => (
  <div className={cn(className, 'form-control', { 'mb-4': !noBottomMargin })}>
    {(label || hintTopRight) && (
      <label className="label">
        {label && <span className="label-text">{label}</span>}
        {hintTopRight && <span className="label-text-alt">{hintTopRight}</span>}
      </label>
    )}
    {children}
    {(hintBottomLeft || hintBottomRight) && (
      <label className="label">
        {hintBottomLeft && (
          <span className="label-text-alt">{hintBottomLeft}</span>
        )}
        {hintBottomRight && (
          <span className="label-text-alt">{hintBottomRight}</span>
        )}
      </label>
    )}
  </div>
);
