import React, { ReactNode } from 'react';
import Head from 'next/head';
import { useTheme } from '../../../context/ThemeContext';
import { SunIcon as SunIconOutline } from '@heroicons/react/outline';
import { SunIcon as SunIconSolid } from '@heroicons/react/solid';

type PortalContentProps = {
  title: string;
  children?: ReactNode;
  subtitle?: string;
};

export const PortalContent: React.FC<PortalContentProps> = ({
  children,
  title,
  subtitle,
}) => {
  const { theme, toggleTheme } = useTheme();

  return (
    <>
      <Head>
        <title>{title}</title>
      </Head>
      <div className="card-body block">
        <div className="flex space-x-8">
          <p className="font-semibold mb-4">{subtitle}</p>
          <button
            className="btn btn-sm btn-ghost"
            onClick={() => toggleTheme()}
          >
            {theme === 'light' ? (
              <SunIconOutline width={24} />
            ) : (
              <SunIconSolid width={24} />
            )}
          </button>
        </div>
        {children}
      </div>
    </>
  );
};
