import React, { createContext, useContext, useState } from 'react';
import { WithChildren } from '../types/components';

export type CurrentDownloads = Record<string, boolean | undefined>;

export type CurrentDownloadsContextProps = {
  downloads: CurrentDownloads;
  setIsDownloading: (link: string, downloading?: boolean) => void;
};

export const CurrentDownloadsContext =
  createContext<CurrentDownloadsContextProps>({
    downloads: {},
    setIsDownloading: () => {},
  });

export const useCurrentDownloads = () => useContext(CurrentDownloadsContext);

export const CurrentDownloadsContextProvider: React.FC<WithChildren> = ({
  children,
}) => {
  const [downloads, setDownloads] = useState<CurrentDownloads>({});

  const setIsDownloading = (link: string, downloading?: boolean) =>
    setDownloads((prev) => ({
      ...prev,
      [link]: downloading,
    }));

  return (
    <CurrentDownloadsContext.Provider value={{ downloads, setIsDownloading }}>
      {children}
    </CurrentDownloadsContext.Provider>
  );
};
