import { DynamicArrayInput, resolveDynamicArrayInput } from './helpers';

export const DEFAULT_PAGE_SIZE = 10;
export const DEFAULT_PAGINATION_PROPS: PaginationProps = {
  page: 1,
  pageSize: DEFAULT_PAGE_SIZE,
};

export type PaginationProps = {
  page?: number;
  pageSize?: number;
};

export type PaginationResultProps = {
  page: number;
  pageSize: number;
  total: number;
};

export const paginate = <T>(
  input: DynamicArrayInput<T>,
  { page = 1, pageSize = DEFAULT_PAGE_SIZE }: PaginationProps,
): T[] => {
  const start = (page - 1) * pageSize;
  return resolveDynamicArrayInput(input).slice(start, start + pageSize);
};

export const getNumberOfPages = <T>(
  input: DynamicArrayInput<T>,
  pageSize: number = DEFAULT_PAGE_SIZE,
): number => {
  const totalItems = resolveDynamicArrayInput(input).length;

  if (totalItems === 0) {
    return 0;
  }

  return Math.ceil(totalItems / pageSize);
};
