import { EncryptionKeyParams } from './encryption';
import { FileOptions } from './files';

export const LOCAL_STORAGE_VAULT = 'axiom_vault';

export const INITIAL_VAULT: Vault = {
  files: [],
};

export enum VaultObjectKey {
  Files = 'files',
}

export enum VaultFileObjectKey {
  Filename = 'name',
  FileType = 'type',
  LastModified = 'lm',
  CID = 'cid',
  FileOptions = 'opts',
  Encryption = 'enc',
}

export type Vault = {
  [VaultObjectKey.Files]: VaultFile[];
};

const initVault = (): void => {
  if (!localStorage.getItem(LOCAL_STORAGE_VAULT)) {
    localStorage.setItem(LOCAL_STORAGE_VAULT, JSON.stringify(INITIAL_VAULT));
  }
};

const getVault = (): Vault => {
  return JSON.parse(localStorage.getItem(LOCAL_STORAGE_VAULT) ?? '{}');
};

const updateVault = (input: Vault): void => {
  const vault = getVault();

  const newVault: Vault = {
    ...vault,
    ...input,
  };

  localStorage.setItem(LOCAL_STORAGE_VAULT, JSON.stringify(newVault));
};

export type VaultFile = {
  [VaultFileObjectKey.Filename]: string;
  [VaultFileObjectKey.FileType]: string;
  [VaultFileObjectKey.LastModified]: number;
  [VaultFileObjectKey.CID]: string;
  [VaultFileObjectKey.FileOptions]: FileOptions;
  [VaultFileObjectKey.Encryption]?: EncryptionKeyParams;
};

const getFiles = (): VaultFile[] => {
  return getVault()[VaultObjectKey.Files];
};

const addFile = (
  file: File,
  cid: string,
  fileOptions: FileOptions,
  encryptionKeyParams: EncryptionKeyParams,
): void => {
  const files = [...getVault().files];

  files.push({
    [VaultFileObjectKey.Filename]: file.name,
    [VaultFileObjectKey.FileType]: file.type,
    [VaultFileObjectKey.LastModified]: file.lastModified,
    [VaultFileObjectKey.CID]: cid,
    [VaultFileObjectKey.FileOptions]: fileOptions,
    [VaultFileObjectKey.Encryption]: fileOptions.encrypt
      ? encryptionKeyParams
      : undefined,
  });

  updateVault({
    [VaultObjectKey.Files]: files,
  });
};

const clearFiles = (): void => {
  updateVault({
    [VaultObjectKey.Files]: [],
  });
};

const vault = {
  initVault,
  getVault,
  updateVault,
  getFiles,
  addFile,
  clearFiles,
};

export default vault;
